Free Genealogy & Ancestry Search Engine
Description: With billions of names, years & places, Mocavo is your source for free ancestry records. Upload your family tree and begin your family history search today.
Keywords: free ancestry, free genealogy, free family tree, free family history, genealogy search free, ancestry search free

# Discovering your family history should be easy.

#### Create a Free Account Now

× Please email support@mocavo.com
I am a … Female Male
My first name
My last name

Please enter your full name so we can get started.

My e-mail address
Create a password

Please provide an e-mail address so we can send you new discoveries and connections!

Please provide a password that is at least 6 characters.

Please fill out all of the fields before signing up.

“I found a whole new publication with my entire family history here. It's very exciting!” - Erin

“All my future genealogy searches will start on Mocavo” - Dick Eastman

“I had been searching for 28 years for a good friend of mine. I found her in five minutes using Mocavo.” - K. Glenn

#### Which Surnames Are You Researching?
This Will Help Us Find Content Relevant to Your Research

First surname
Second surname
Third surname

Please tell us three surnames to research.

Skip this and let me get started on my own

## Experience the Best in Family Research

- Search millions of genealogy related pages for that brick wall in your family tree.
- Upload and share your family tree and historic documents with the community.
- Collaborate in the Community Forums on family history topics to help with research.

## Browse Thousands of New Records

## Browse by Category

##### BMD

- Baptism
- Birth
- Burial
- Christening
- Death
- Divorce
- Marriage

##### Directories

- City or Area
- Organizational
- Professional

##### Documents & Records

- Bank & Insurance
- Criminal & Court
- Government
- Immigration
- Land
- Passenger Lists
- Tax
- Wills & Estates

##### Histories

- Church
- City
- County
- Ethnic Group
- Family & Biographies
- Local or Place
- Military
- Native American
- Royalty
- Society & Organization
- State

##### Military

- Casualties
- Draft
- Enlistment
- Pensions
- Service
- Soldiers, Veterans, Prisoner Rolls & Lists

##### Newspapers

##### Yearbooks

- College
- High School
- Navy Cruisebooks
- Other

##### Other

- Atlases
- Catalogs & Bibliographies
- Cemeteries
- Census
- Correspondence
- Discourses & Writings
- Family Trees
- Gazeteers
- Interviews & Personal Histories
- Journals
- Letters
- Maps
- Obituaries
- Periodicals & Magazines
- Pictures
- Proceedings & Programs
- Reference Dictionaries & Almanacs
- Travel Logs
- Voter Lists

## Browse by Location

##### Australia

##### Canada

- Alberta
- British Columbia
- Canada
- Manitoba
- New Brunswick
- Newfoundland & Labrador
- Northwest Territories
- Nova Scotia
- Nunavut
- Ontario
- Prince Edward Island
- Quebec
- Saskatchewan
- Yukon

##### Europe

##### France

##### Germany

##### Ireland

##### Italy

##### New Zealand

##### Northern Ireland

##### United Kingdom

- British Indian Ocean Territories
- England
- Great Britain
- Isle of Man
- Scotland
- United Kingdom
- Wales

##### United States

##### Regions

- Midwest
- New England
- Puerto Rico
- Rocky Mountain
- South
- United States
- West

##### States

- Alabama
- Alaska
- Arizona
- Arkansas
- California
- Colorado
- Connecticut
- Delaware
- District of Columbia
- Florida
- Georgia
- Hawaii
- Idaho
- Illinois
- Indiana
- Iowa
- Kansas
- Kentucky
- Louisiana
- Maine
- Maryland
- Massachusetts
- Michigan
- Minnesota
- Mississippi
- Missouri
- Montana
- Nebraska
- Nevada
- New Hampshire
- New Jersey
- New Mexico
- New York
- North Carolina
- North Dakota
- Ohio
- Oklahoma
- Oregon
- Pennsylvania
- Rhode Island
- South Carolina
- South Dakota
- Tennessee
- Texas
- Utah
- Vermont
- Virginia
- Washington
- West Virginia
- Wisconsin
- Wyoming

##### World

## Browse by Date

##### Pre-1000

##### 1000's

##### 1100's

##### 1200's

##### 1300's

##### 1400's

##### 1500's

##### 1600's

##### 1700's

##### 1800's

##### 1900's

##### 2000's

## Upload Your Story with Mocavo

- ##

  ### Upload
  a Tree

- ##

  ### Upload
  a Document

- ##

  ### Upload
  a Database

## Upload Your Family Tree

- ##

  ### Upload
  from Desktop

## Upload a Document

- ##

  ### Upload
  from Desktop

### Select Family Tree File (Step 1 of 2)

Choose File from Your Computer

### Upload a Family Tree (Step 2 of 2)

Give this Tree a Name

### Upload a Document (Step 1 of 2)

Choose File

### Suggest a Site

We are always on the lookout for new resources to add to our database. If you have a website that you believe would benefit our community, please let us know.

Website URL (please provide a URL)
Your Email (please provide a valid email)
Brief Description (please provide a brief description)

### Upload a Database

We are always on the lookout for new records to add to our database. If you have a resource that you would like to contribute to our community, please let us know and we will be in touch as soon as possible.

Your Name Your E-Mail Please Describe Your Database Please Categorize Your Database